import tomli
import tomli_w
from pathlib import Path
from .models import VersionType
from .formatters import VersionFormatter


class PyProjectBumper:
    def __init__(self, file_path: Path):
        self.file_path = file_path
        self.data = self._read_pyproject()
        self.config = self.data.get("tool", {}).get("pyproject-bumper", {})
        self.formatter = VersionFormatter(self.config)

    def _read_pyproject(self) -> dict:
        """Lee el archivo pyproject.toml."""
        with open(self.file_path, "rb") as f:
            return tomli.load(f)

    def _write_pyproject(self):
        """Escribe el archivo pyproject.toml."""
        with open(self.file_path, "wb") as f:
            tomli_w.dump(self.data, f)

    def bump(self, version_type: VersionType) -> str:
        """Incrementa la versión según el tipo especificado."""
        current_version = self.data["project"]["version"]
        new_version = self.formatter.bump_version(current_version, version_type)
        self.data["project"]["version"] = new_version
        self._write_pyproject()
        return new_version
