import argparse
from pathlib import Path
from .models import VersionType
from .bumper import PyProjectBumper


def main():
    parser = argparse.ArgumentParser(
        description="Incrementa la versión en pyproject.toml"
    )
    parser.add_argument(
        "--type",
        type=str,
        choices=["major", "minor", "patch", "date"],
        required=True,
        help="Tipo de incremento de versión",
    )
    parser.add_argument(
        "--file",
        type=str,
        default="pyproject.toml",
        help="Ruta al archivo pyproject.toml",
    )

    args = parser.parse_args()
    file_path = Path(args.file)

    if not file_path.exists():
        print(f"Error: No se encontró el archivo {file_path}")
        return

    try:
        bumper = PyProjectBumper(file_path)
        version_type = VersionType(args.type)
        old_version = bumper.data["project"]["version"]
        new_version = bumper.bump(version_type)

        print(f"Versión actualizada: {old_version} -> {new_version}")

    except Exception as e:
        print(f"Error al procesar el archivo: {e}")
